/* Copyright (c) 1994 Sanjay Ghemawat */
#include <tcl.h>
#include "commands.h"

static char icalInit[] = {
#include "startup.h"
, '\0'
};

int Ical_Init(Tcl_Interp* tcl) {
    Tcl_CreateCommand(tcl, "calendar",     Cmd_CreateCalendar,	NULL, NULL);
    Tcl_CreateCommand(tcl, "notice",       Cmd_CreateNotice,	NULL, NULL);
    Tcl_CreateCommand(tcl, "appointment",  Cmd_CreateAppt,	NULL, NULL);
    Tcl_CreateCommand(tcl, "date",         Cmd_Date,		NULL, NULL);
    Tcl_CreateCommand(tcl, "time",         Cmd_Time,		NULL, NULL);
    Tcl_CreateCommand(tcl, "de_monthdays", Cmd_MonthDays,	NULL, NULL);
    Tcl_CreateCommand(tcl, "de_interest",  Cmd_InterestTags,	NULL, NULL);

    return Tcl_Eval(tcl, icalInit);
}
